@@ -552,4 +552,10 @@ impl<'a> Info<'a> {
             true
         }
     }
+
+    /// Returns true if the element was deleted.
+    /// This is a convenience function that just returns the inverse of `Info::visible`.
+    pub fn deleted(&self) -> bool {
+        !self.visible()
+    }
 }
